# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/model.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gateway/model.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9c\x05\n\x05Model\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x14 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12+\n\x05state\x18\x06 \x01(\x0e\x32\x14.gateway.Model.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12)\n\x04kind\x18\x04 \x01(\x0e\x32\x13.gateway.Model.KindB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rdeployment_id\x18\x0f \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x17\n\ngithub_url\x18\x15 \x01(\tB\x03\xe0\x41\x01\x12\x1d\n\x10hugging_face_url\x18\x16 \x01(\tB\x03\xe0\x41\x01\x12=\n\x12\x62\x61se_model_details\x18\x17 \x01(\x0b\x32\x19.gateway.BaseModelDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0cpeft_details\x18\x10 \x01(\x0b\x32\x14.gateway.PEFTDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x13\n\x06public\x18\x13 \x01(\x08\x42\x03\xe0\x41\x01\"k\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\x0e\n\nUNDEPLOYED\x10\x02\x12\x0f\n\x0bUNDEPLOYING\x10\x03\x12\r\n\tDEPLOYING\x10\x04\x12\x0c\n\x08\x44\x45PLOYED\x10\x05\"B\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x11\n\rHF_BASE_MODEL\x10\x01\x12\x11\n\rHF_PEFT_ADDON\x10\x02\"\xf4\x01\n\x10\x42\x61seModelDetails\x12\x1a\n\nworld_size\x18\x01 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12M\n\x11\x63heckpoint_format\x18\x02 \x01(\x0e\x32*.gateway.BaseModelDetails.CheckpointFormatB\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11huggingface_files\x18\x03 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\"R\n\x10\x43heckpointFormat\x12!\n\x1d\x43HECKPOINT_FORMAT_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x0f\n\x0bHUGGINGFACE\x10\x02\"\\\n\x0bPEFTDetails\x12\x1a\n\nbase_model\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x11\n\x01r\x18\x02 \x01(\x05\x42\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0etarget_modules\x18\x03 \x03(\tB\x06\xe0\x41\x02\xe0\x41\x05\"d\n\x12\x43reateModelRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x05model\x18\x02 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"$\n\x0fGetModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"C\n\x12\x44\x65ployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1a\n\rdeployment_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\")\n\x14UndeployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xc4\x01\n\x1dGetModelUploadEndpointRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12Y\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32:.gateway.GetModelUploadEndpointRequest.FilenameToSizeEntryB\x03\xe0\x41\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xc1\x01\n\x1eGetModelUploadEndpointResponse\x12\x62\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x41.gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x1aValidateModelUploadRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x85\x01\n\x11ListModelsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"a\n\x12ListModelsResponse\x12\x1e\n\x06models\x18\x01 \x03(\x0b\x32\x0e.gateway.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"8\n\x12UpdateModelRequest\x12\"\n\x05model\x18\x01 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\"\'\n\x12\x44\x65leteModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.model_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _MODEL.fields_by_name['name']._options = None
  _MODEL.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['display_name']._options = None
  _MODEL.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['description']._options = None
  _MODEL.fields_by_name['description']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['create_time']._options = None
  _MODEL.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['state']._options = None
  _MODEL.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['status']._options = None
  _MODEL.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['kind']._options = None
  _MODEL.fields_by_name['kind']._serialized_options = b'\340A\001\340A\005'
  _MODEL.fields_by_name['deployment_id']._options = None
  _MODEL.fields_by_name['deployment_id']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['github_url']._options = None
  _MODEL.fields_by_name['github_url']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['hugging_face_url']._options = None
  _MODEL.fields_by_name['hugging_face_url']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['base_model_details']._options = None
  _MODEL.fields_by_name['base_model_details']._serialized_options = b'\340A\001\340A\005'
  _MODEL.fields_by_name['peft_details']._options = None
  _MODEL.fields_by_name['peft_details']._serialized_options = b'\340A\001\340A\005'
  _MODEL.fields_by_name['public']._options = None
  _MODEL.fields_by_name['public']._serialized_options = b'\340A\001'
  _BASEMODELDETAILS.fields_by_name['world_size']._options = None
  _BASEMODELDETAILS.fields_by_name['world_size']._serialized_options = b'\340A\001\340A\005'
  _BASEMODELDETAILS.fields_by_name['checkpoint_format']._options = None
  _BASEMODELDETAILS.fields_by_name['checkpoint_format']._serialized_options = b'\340A\001\340A\005'
  _BASEMODELDETAILS.fields_by_name['huggingface_files']._options = None
  _BASEMODELDETAILS.fields_by_name['huggingface_files']._serialized_options = b'\340A\001\340A\005'
  _PEFTDETAILS.fields_by_name['base_model']._options = None
  _PEFTDETAILS.fields_by_name['base_model']._serialized_options = b'\340A\002\340A\005'
  _PEFTDETAILS.fields_by_name['r']._options = None
  _PEFTDETAILS.fields_by_name['r']._serialized_options = b'\340A\002\340A\005'
  _PEFTDETAILS.fields_by_name['target_modules']._options = None
  _PEFTDETAILS.fields_by_name['target_modules']._serialized_options = b'\340A\002\340A\005'
  _CREATEMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEMODELREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEMODELREQUEST.fields_by_name['model']._options = None
  _CREATEMODELREQUEST.fields_by_name['model']._serialized_options = b'\340A\002'
  _CREATEMODELREQUEST.fields_by_name['model_id']._options = None
  _CREATEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _GETMODELREQUEST.fields_by_name['name']._options = None
  _GETMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DEPLOYMODELREQUEST.fields_by_name['name']._options = None
  _DEPLOYMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DEPLOYMODELREQUEST.fields_by_name['deployment_id']._options = None
  _DEPLOYMODELREQUEST.fields_by_name['deployment_id']._serialized_options = b'\340A\002'
  _UNDEPLOYMODELREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._options = None
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._serialized_options = b'8\001'
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['name']._options = None
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size']._options = None
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size']._serialized_options = b'\340A\002'
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._options = None
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._serialized_options = b'8\001'
  _VALIDATEMODELUPLOADREQUEST.fields_by_name['name']._options = None
  _VALIDATEMODELUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEMODELREQUEST.fields_by_name['model']._serialized_options = b'\340A\002'
  _DELETEMODELREQUEST.fields_by_name['name']._options = None
  _DELETEMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _MODEL._serialized_start=121
  _MODEL._serialized_end=789
  _MODEL_STATE._serialized_start=614
  _MODEL_STATE._serialized_end=721
  _MODEL_KIND._serialized_start=723
  _MODEL_KIND._serialized_end=789
  _BASEMODELDETAILS._serialized_start=792
  _BASEMODELDETAILS._serialized_end=1036
  _BASEMODELDETAILS_CHECKPOINTFORMAT._serialized_start=954
  _BASEMODELDETAILS_CHECKPOINTFORMAT._serialized_end=1036
  _PEFTDETAILS._serialized_start=1038
  _PEFTDETAILS._serialized_end=1130
  _CREATEMODELREQUEST._serialized_start=1132
  _CREATEMODELREQUEST._serialized_end=1232
  _GETMODELREQUEST._serialized_start=1234
  _GETMODELREQUEST._serialized_end=1270
  _DEPLOYMODELREQUEST._serialized_start=1272
  _DEPLOYMODELREQUEST._serialized_end=1339
  _UNDEPLOYMODELREQUEST._serialized_start=1341
  _UNDEPLOYMODELREQUEST._serialized_end=1382
  _GETMODELUPLOADENDPOINTREQUEST._serialized_start=1385
  _GETMODELUPLOADENDPOINTREQUEST._serialized_end=1581
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._serialized_start=1528
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._serialized_end=1581
  _GETMODELUPLOADENDPOINTRESPONSE._serialized_start=1584
  _GETMODELUPLOADENDPOINTRESPONSE._serialized_end=1777
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._serialized_start=1718
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._serialized_end=1777
  _VALIDATEMODELUPLOADREQUEST._serialized_start=1779
  _VALIDATEMODELUPLOADREQUEST._serialized_end=1826
  _LISTMODELSREQUEST._serialized_start=1829
  _LISTMODELSREQUEST._serialized_end=1962
  _LISTMODELSRESPONSE._serialized_start=1964
  _LISTMODELSRESPONSE._serialized_end=2061
  _UPDATEMODELREQUEST._serialized_start=2063
  _UPDATEMODELREQUEST._serialized_end=2119
  _DELETEMODELREQUEST._serialized_start=2121
  _DELETEMODELREQUEST._serialized_end=2160
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gateway/snapshot.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa0\x02\n\x08Snapshot\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12.\n\x05state\x18\x03 \x01(\x0e\x32\x17.gateway.Snapshot.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x04 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\timage_ref\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"\'\n\x12GetSnapshotRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListSnapshotsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"j\n\x15ListSnapshotsResponse\x12$\n\tsnapshots\x18\x01 \x03(\x0b\x32\x11.gateway.Snapshot\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.snapshot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _SNAPSHOT.fields_by_name['name']._options = None
  _SNAPSHOT.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _SNAPSHOT.fields_by_name['create_time']._options = None
  _SNAPSHOT.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _SNAPSHOT.fields_by_name['state']._options = None
  _SNAPSHOT.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _SNAPSHOT.fields_by_name['status']._options = None
  _SNAPSHOT.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _SNAPSHOT.fields_by_name['image_ref']._options = None
  _SNAPSHOT.fields_by_name['image_ref']._serialized_options = b'\340A\003\340A\005'
  _GETSNAPSHOTREQUEST.fields_by_name['name']._options = None
  _GETSNAPSHOTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTSNAPSHOTSREQUEST.fields_by_name['parent']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_size']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_token']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTSNAPSHOTSREQUEST.fields_by_name['filter']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTSNAPSHOTSREQUEST.fields_by_name['order_by']._options = None
  _LISTSNAPSHOTSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _SNAPSHOT._serialized_start=124
  _SNAPSHOT._serialized_end=412
  _SNAPSHOT_STATE._serialized_start=331
  _SNAPSHOT_STATE._serialized_end=412
  _GETSNAPSHOTREQUEST._serialized_start=414
  _GETSNAPSHOTREQUEST._serialized_end=453
  _LISTSNAPSHOTSREQUEST._serialized_start=456
  _LISTSNAPSHOTSREQUEST._serialized_end=592
  _LISTSNAPSHOTSRESPONSE._serialized_start=594
  _LISTSNAPSHOTSRESPONSE._serialized_end=700
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import account_pb2 as gateway_dot_account__pb2
from . import aws_iam_role_binding_pb2 as gateway_dot_aws__iam__role__binding__pb2
from . import batch_job_pb2 as gateway_dot_batch__job__pb2
from . import cluster_pb2 as gateway_dot_cluster__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import environment_pb2 as gateway_dot_environment__pb2
from . import model_pb2 as gateway_dot_model__pb2
from . import node_pool_pb2 as gateway_dot_node__pool__pb2
from . import sign_in_pb2 as gateway_dot_sign__in__pb2
from . import snapshot_pb2 as gateway_dot_snapshot__pb2
from . import user_pb2 as gateway_dot_user__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/gateway.proto\x12\x07gateway\x1a\x15gateway/account.proto\x1a\"gateway/aws_iam_role_binding.proto\x1a\x17gateway/batch_job.proto\x1a\x15gateway/cluster.proto\x1a\x18gateway/deployment.proto\x1a\x19gateway/environment.proto\x1a\x13gateway/model.proto\x1a\x17gateway/node_pool.proto\x1a\x15gateway/sign_in.proto\x1a\x16gateway/snapshot.proto\x1a\x12gateway/user.proto\x1a\x1bgoogle/protobuf/empty.proto2\xa4%\n\x07Gateway\x12:\n\x06SignIn\x12\x16.gateway.SignInRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x11GetOAuthArguments\x12!.gateway.GetOAuthArgumentsRequest\x1a\".gateway.GetOAuthArgumentsResponse\"\x00\x12\x42\n\rCreateAccount\x12\x1d.gateway.CreateAccountRequest\x1a\x10.gateway.Account\"\x00\x12<\n\nGetAccount\x12\x1a.gateway.GetAccountRequest\x1a\x10.gateway.Account\"\x00\x12M\n\x0cListAccounts\x12\x1c.gateway.ListAccountsRequest\x1a\x1d.gateway.ListAccountsResponse\"\x00\x12\x42\n\rUpdateAccount\x12\x1d.gateway.UpdateAccountRequest\x1a\x10.gateway.Account\"\x00\x12H\n\rDeleteAccount\x12\x1d.gateway.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x0e\x43reateBatchJob\x12\x1e.gateway.CreateBatchJobRequest\x1a\x11.gateway.BatchJob\"\x00\x12?\n\x0bGetBatchJob\x12\x1b.gateway.GetBatchJobRequest\x1a\x11.gateway.BatchJob\"\x00\x12P\n\rListBatchJobs\x12\x1d.gateway.ListBatchJobsRequest\x1a\x1e.gateway.ListBatchJobsResponse\"\x00\x12J\n\x0e\x44\x65leteBatchJob\x12\x1e.gateway.DeleteBatchJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x14\x42\x61tchDeleteBatchJobs\x12$.gateway.BatchDeleteBatchJobsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12J\n\x0e\x43\x61ncelBatchJob\x12\x1e.gateway.CancelBatchJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\rCreateCluster\x12\x1d.gateway.CreateClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12<\n\nGetCluster\x12\x1a.gateway.GetClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12M\n\x0cListClusters\x12\x1c.gateway.ListClustersRequest\x1a\x1d.gateway.ListClustersResponse\"\x00\x12\x42\n\rUpdateCluster\x12\x1d.gateway.UpdateClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12H\n\rDeleteCluster\x12\x1d.gateway.DeleteClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x18GetClusterConnectionInfo\x12(.gateway.GetClusterConnectionInfoRequest\x1a\x1e.gateway.ClusterConnectionInfo\"\x00\x12N\n\x11\x43reateEnvironment\x12!.gateway.CreateEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12H\n\x0eGetEnvironment\x12\x1e.gateway.GetEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12Y\n\x10ListEnvironments\x12 .gateway.ListEnvironmentsRequest\x1a!.gateway.ListEnvironmentsResponse\"\x00\x12N\n\x11UpdateEnvironment\x12!.gateway.UpdateEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12P\n\x11\x44\x65leteEnvironment\x12!.gateway.DeleteEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x17\x42\x61tchDeleteEnvironments\x12\'.gateway.BatchDeleteEnvironmentsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12R\n\x12\x43onnectEnvironment\x12\".gateway.ConnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x15\x44isconnectEnvironment\x12%.gateway.DisconnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12?\n\x0bGetSnapshot\x12\x1b.gateway.GetSnapshotRequest\x1a\x11.gateway.Snapshot\"\x00\x12P\n\rListSnapshots\x12\x1d.gateway.ListSnapshotsRequest\x1a\x1e.gateway.ListSnapshotsResponse\"\x00\x12V\n\x0fGetBatchJobLogs\x12\x1f.gateway.GetBatchJobLogsRequest\x1a .gateway.GetBatchJobLogsResponse\"\x00\x12\x45\n\x0e\x43reateNodePool\x12\x1e.gateway.CreateNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12?\n\x0bGetNodePool\x12\x1b.gateway.GetNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12P\n\rListNodePools\x12\x1d.gateway.ListNodePoolsRequest\x1a\x1e.gateway.ListNodePoolsResponse\"\x00\x12\x45\n\x0eUpdateNodePool\x12\x1e.gateway.UpdateNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12J\n\x0e\x44\x65leteNodePool\x12\x1e.gateway.DeleteNodePoolRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x14\x42\x61tchDeleteNodePools\x12$.gateway.BatchDeleteNodePoolsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\x10GetNodePoolStats\x12 .gateway.GetNodePoolStatsRequest\x1a\x16.gateway.NodePoolStats\"\x00\x12\x39\n\nCreateUser\x12\x1a.gateway.CreateUserRequest\x1a\r.gateway.User\"\x00\x12\x33\n\x07GetUser\x12\x17.gateway.GetUserRequest\x1a\r.gateway.User\"\x00\x12\x44\n\tListUsers\x12\x19.gateway.ListUsersRequest\x1a\x1a.gateway.ListUsersResponse\"\x00\x12\x39\n\nUpdateUser\x12\x1a.gateway.UpdateUserRequest\x1a\r.gateway.User\"\x00\x12\x42\n\nDeleteUser\x12\x1a.gateway.DeleteUserRequest\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\x0b\x43reateModel\x12\x1b.gateway.CreateModelRequest\x1a\x0e.gateway.Model\"\x00\x12\x36\n\x08GetModel\x12\x18.gateway.GetModelRequest\x1a\x0e.gateway.Model\"\x00\x12G\n\nListModels\x12\x1a.gateway.ListModelsRequest\x1a\x1b.gateway.ListModelsResponse\"\x00\x12<\n\x0bUpdateModel\x12\x1b.gateway.UpdateModelRequest\x1a\x0e.gateway.Model\"\x00\x12\x44\n\x0b\x44\x65leteModel\x12\x1b.gateway.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12k\n\x16GetModelUploadEndpoint\x12&.gateway.GetModelUploadEndpointRequest\x1a\'.gateway.GetModelUploadEndpointResponse\"\x00\x12T\n\x13ValidateModelUpload\x12#.gateway.ValidateModelUploadRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x44\n\x0b\x44\x65ployModel\x12\x1b.gateway.DeployModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12H\n\rUndeployModel\x12\x1d.gateway.UndeployModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12K\n\x10\x43reateDeployment\x12 .gateway.CreateDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12\x45\n\rGetDeployment\x12\x1d.gateway.GetDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12I\n\x0fStartDeployment\x12\x1f.gateway.StartDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12V\n\x0fListDeployments\x12\x1f.gateway.ListDeploymentsRequest\x1a .gateway.ListDeploymentsResponse\"\x00\x12K\n\x10UpdateDeployment\x12 .gateway.UpdateDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12N\n\x10\x44\x65leteDeployment\x12 .gateway.DeleteDeploymentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x17\x43reateAwsIamRoleBinding\x12\'.gateway.CreateAwsIamRoleBindingRequest\x1a\x1a.gateway.AwsIamRoleBinding\"\x00\x12k\n\x16ListAwsIamRoleBindings\x12&.gateway.ListAwsIamRoleBindingsRequest\x1a\'.gateway.ListAwsIamRoleBindingsResponse\"\x00\x12\\\n\x17\x44\x65leteAwsIamRoleBinding\x12\'.gateway.DeleteAwsIamRoleBindingRequest\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\x10ReconcileCluster\x12 .gateway.ReconcileClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x11ReconcileNodePool\x12!.gateway.ReconcileNodePoolRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.gateway_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _GATEWAY._serialized_start=337
  _GATEWAY._serialized_end=5109
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/batch_job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/batch_job.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x08\n\x08\x42\x61tchJob\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\t \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x36\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x34\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\ncreated_by\x18\r \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1c\n\x0cnode_pool_id\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1b\n\x0bsnapshot_id\x18\x13 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x19\n\tnum_ranks\x18\x0b \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x38\n\x08\x65nv_vars\x18\x06 \x03(\x0b\x32\x1e.gateway.BatchJob.EnvVarsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04role\x18\x11 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0fpython_executor\x18\x07 \x01(\x0b\x32\x17.gateway.PythonExecutorH\x00\x12\x36\n\x11notebook_executor\x18\x08 \x01(\x0b\x32\x19.gateway.NotebookExecutorH\x00\x12\x30\n\x0eshell_executor\x18\x10 \x01(\x0b\x32\x16.gateway.ShellExecutorH\x00\x12\x19\n\timage_ref\x18\n \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12?\n\x0b\x61nnotations\x18\x12 \x03(\x0b\x32\".gateway.BatchJob.AnnotationsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12.\n\x05state\x18\x04 \x01(\x0e\x32\x17.gateway.BatchJob.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\x06status\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x0e\n\x06shared\x18\x14 \x01(\x08\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x07\x12\n\n\x06QUEUED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0e\n\nCANCELLING\x10\x08\x12\r\n\tCANCELLED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\tB\n\n\x08\x65xecutor\"W\n\x15\x43reateBatchJobRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12)\n\tbatch_job\x18\x02 \x01(\x0b\x32\x11.gateway.BatchJobB\x03\xe0\x41\x02\"\'\n\x12GetBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"k\n\x15ListBatchJobsResponse\x12%\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x11.gateway.BatchJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"*\n\x15\x44\x65leteBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"F\n\x1b\x42\x61tchDeleteBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\"*\n\x15\x43\x61ncelBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xd3\x01\n\x16GetBatchJobLogsRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\r\n\x05ranks\x18\x03 \x03(\x05\x12\x16\n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x05 \x01(\tB\x03\xe0\x41\x01\x12\x33\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x07 \x01(\tB\x03\xe0\x41\x01\x12\x1c\n\x0fstart_from_head\x18\x08 \x01(\x08\x42\x03\xe0\x41\x01\"V\n\x17GetBatchJobLogsResponse\x12\"\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x11.gateway.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xbb\x01\n\x0ePythonExecutor\x12<\n\x0btarget_type\x18\x01 \x01(\x0e\x32\".gateway.PythonExecutor.TargetTypeB\x03\xe0\x41\x02\x12\x13\n\x06target\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04\x61rgs\x18\x03 \x03(\tB\x03\xe0\x41\x01\"C\n\nTargetType\x12\x1b\n\x17TARGET_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MODULE\x10\x01\x12\x0c\n\x08\x46ILENAME\x10\x02\"%\n\rShellExecutor\x12\x14\n\x07\x63ommand\x18\x01 \x01(\tB\x03\xe0\x41\x02\"2\n\x10NotebookExecutor\x12\x1e\n\x11notebook_filename\x18\x01 \x01(\tB\x03\xe0\x41\x02\"W\n\x08LogEntry\x12,\n\x08log_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rank\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tB\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.batch_job_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _BATCHJOB_ENVVARSENTRY._options = None
  _BATCHJOB_ENVVARSENTRY._serialized_options = b'8\001'
  _BATCHJOB_ANNOTATIONSENTRY._options = None
  _BATCHJOB_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _BATCHJOB.fields_by_name['name']._options = None
  _BATCHJOB.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['display_name']._options = None
  _BATCHJOB.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _BATCHJOB.fields_by_name['create_time']._options = None
  _BATCHJOB.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['start_time']._options = None
  _BATCHJOB.fields_by_name['start_time']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['end_time']._options = None
  _BATCHJOB.fields_by_name['end_time']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['created_by']._options = None
  _BATCHJOB.fields_by_name['created_by']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['node_pool_id']._options = None
  _BATCHJOB.fields_by_name['node_pool_id']._serialized_options = b'\340A\002\340A\005'
  _BATCHJOB.fields_by_name['environment_id']._options = None
  _BATCHJOB.fields_by_name['environment_id']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['snapshot_id']._options = None
  _BATCHJOB.fields_by_name['snapshot_id']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['num_ranks']._options = None
  _BATCHJOB.fields_by_name['num_ranks']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['env_vars']._options = None
  _BATCHJOB.fields_by_name['env_vars']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['role']._options = None
  _BATCHJOB.fields_by_name['role']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['image_ref']._options = None
  _BATCHJOB.fields_by_name['image_ref']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['annotations']._options = None
  _BATCHJOB.fields_by_name['annotations']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['state']._options = None
  _BATCHJOB.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['status']._options = None
  _BATCHJOB.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _CREATEBATCHJOBREQUEST.fields_by_name['parent']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _GETBATCHJOBREQUEST.fields_by_name['name']._options = None
  _GETBATCHJOBREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTBATCHJOBSREQUEST.fields_by_name['parent']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTBATCHJOBSREQUEST.fields_by_name['page_size']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['page_token']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['filter']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['order_by']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _DELETEBATCHJOBREQUEST.fields_by_name['name']._options = None
  _DELETEBATCHJOBREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['parent']._options = None
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['names']._options = None
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['names']._serialized_options = b'\340A\002'
  _CANCELBATCHJOBREQUEST.fields_by_name['name']._options = None
  _CANCELBATCHJOBREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['name']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_size']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_token']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_time']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_time']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['filter']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_from_head']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_from_head']._serialized_options = b'\340A\001'
  _PYTHONEXECUTOR.fields_by_name['target_type']._options = None
  _PYTHONEXECUTOR.fields_by_name['target_type']._serialized_options = b'\340A\002'
  _PYTHONEXECUTOR.fields_by_name['target']._options = None
  _PYTHONEXECUTOR.fields_by_name['target']._serialized_options = b'\340A\002'
  _PYTHONEXECUTOR.fields_by_name['args']._options = None
  _PYTHONEXECUTOR.fields_by_name['args']._serialized_options = b'\340A\001'
  _SHELLEXECUTOR.fields_by_name['command']._options = None
  _SHELLEXECUTOR.fields_by_name['command']._serialized_options = b'\340A\002'
  _NOTEBOOKEXECUTOR.fields_by_name['notebook_filename']._options = None
  _NOTEBOOKEXECUTOR.fields_by_name['notebook_filename']._serialized_options = b'\340A\002'
  _BATCHJOB._serialized_start=103
  _BATCHJOB._serialized_end=1162
  _BATCHJOB_ENVVARSENTRY._serialized_start=895
  _BATCHJOB_ENVVARSENTRY._serialized_end=941
  _BATCHJOB_ANNOTATIONSENTRY._serialized_start=943
  _BATCHJOB_ANNOTATIONSENTRY._serialized_end=993
  _BATCHJOB_STATE._serialized_start=996
  _BATCHJOB_STATE._serialized_end=1150
  _CREATEBATCHJOBREQUEST._serialized_start=1164
  _CREATEBATCHJOBREQUEST._serialized_end=1251
  _GETBATCHJOBREQUEST._serialized_start=1253
  _GETBATCHJOBREQUEST._serialized_end=1292
  _LISTBATCHJOBSREQUEST._serialized_start=1295
  _LISTBATCHJOBSREQUEST._serialized_end=1431
  _LISTBATCHJOBSRESPONSE._serialized_start=1433
  _LISTBATCHJOBSRESPONSE._serialized_end=1540
  _DELETEBATCHJOBREQUEST._serialized_start=1542
  _DELETEBATCHJOBREQUEST._serialized_end=1584
  _BATCHDELETEBATCHJOBSREQUEST._serialized_start=1586
  _BATCHDELETEBATCHJOBSREQUEST._serialized_end=1656
  _CANCELBATCHJOBREQUEST._serialized_start=1658
  _CANCELBATCHJOBREQUEST._serialized_end=1700
  _GETBATCHJOBLOGSREQUEST._serialized_start=1703
  _GETBATCHJOBLOGSREQUEST._serialized_end=1914
  _GETBATCHJOBLOGSRESPONSE._serialized_start=1916
  _GETBATCHJOBLOGSRESPONSE._serialized_end=2002
  _PYTHONEXECUTOR._serialized_start=2005
  _PYTHONEXECUTOR._serialized_end=2192
  _PYTHONEXECUTOR_TARGETTYPE._serialized_start=2125
  _PYTHONEXECUTOR_TARGETTYPE._serialized_end=2192
  _SHELLEXECUTOR._serialized_start=2194
  _SHELLEXECUTOR._serialized_end=2231
  _NOTEBOOKEXECUTOR._serialized_start=2233
  _NOTEBOOKEXECUTOR._serialized_end=2283
  _LOGENTRY._serialized_start=2285
  _LOGENTRY._serialized_end=2372
# @@protoc_insertion_point(module_scope)



import httpx
from typing import Dict, Any, Optional, Generator
from httpx_sse import connect_sse, aconnect_sse
import fireworks.client
from .error import (
    AuthenticationError,
    InternalServerError,
    InvalidRequestError,
    PermissionError,
    RateLimitError,
    ServiceUnavailableError,
)


# Helper functions for api key and base url prevent cyclic dependencies
def default_api_key() -> str:
    if fireworks.client.api_key is not None:
        return fireworks.client.api_key
    else:
        raise ValueError(
            "No API key provided. You can set your API key in code using 'fireworks.client.api_key = <API-KEY>', or you can set the environment variable FIREWORKS_API_KEY=<API-KEY>)."
        )


def default_base_url() -> str:
    return fireworks.client.base_url


class FireworksClient:
    """
    Fireworks client class to help with request handling for
    - get
    - post
      - with & without async
      - with & without streaming
    """

    def __init__(self, request_timeout=600, **kwargs) -> None:
        """Initializes the Fireworks client.

        Args:
          request_timeout (int): A request timeout in seconds.
        """
        if "request_timeout" in kwargs:
            request_timeout = kwargs["request_timeout"]
        self.api_key = default_api_key()
        if not self.api_key:
            raise AuthenticationError(
                "No API key provided. You can set your API key in code using 'fireworks.client.api_key = <API-KEY>', or you can set the environment variable FIREWORKS_API_KEY=<API-KEY>)."
            )
        self.base_url = default_base_url()
        self.request_timeout = request_timeout
        self.client_kwargs = kwargs

    def _raise_for_status(self, resp):
        if resp.status_code == 400:
            raise InvalidRequestError(resp.json())
        elif resp.status_code == 401:
            raise AuthenticationError(resp.json())
        elif resp.status_code == 403:
            raise PermissionError(resp.json())
        elif resp.status_code == 404:
            raise InvalidRequestError(resp.json())
        elif resp.status_code == 429:
            raise RateLimitError(resp.json())
        elif resp.status_code == 500:
            raise InternalServerError(resp.json())
        elif resp.status_code == 503:
            raise ServiceUnavailableError(resp.json())
        else:
            resp.raise_for_status()

    async def _async_error_handling(self, resp):
        if resp.is_error:
            await resp.aread()
        self._raise_for_status(resp)

    def _error_handling(self, resp):
        if resp.is_error:
            resp.read()
        self._raise_for_status(resp)

    def _get_request(self, url: str) -> Dict[str, Any]:
        with httpx.Client(
            headers={"Authorization": f"Bearer {self.api_key}"},
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            resp = client.get(url)
            self._error_handling(resp)
            return resp.json()

    def post_request_streaming(
        self, url: str, data: Optional[Dict[str, Any]] = None
    ) -> Generator[str, None, None]:
        with httpx.Client(
            headers={"Authorization": f"Bearer {self.api_key}"},
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            with connect_sse(client, url=url, method="POST", json=data) as event_source:
                self._error_handling(event_source.response)
                for sse in event_source.iter_sse():
                    yield sse.data

    def post_request_non_streaming(
        self, url: str, data: Optional[Dict[str, Any]] = None
    ) -> Dict[str, Any]:
        with httpx.Client(
            headers={"Authorization": f"Bearer {self.api_key}"},
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            response = client.post(url, json=data)
            self._error_handling(response)
            return response.json()

    async def post_request_async_streaming(
        self, url: str, data: Optional[Dict[str, Any]] = None
    ) -> Generator[str, None, None]:
        async with httpx.AsyncClient(
            headers={"Authorization": f"Bearer {self.api_key}"},
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            async with aconnect_sse(
                client, url=url, method="POST", json=data
            ) as event_source:
                await self._async_error_handling(event_source.response)
                async for sse in event_source.aiter_sse():
                    yield sse.data

    async def post_request_async_non_streaming(
        self, url: str, data: Optional[Dict[str, Any]] = None
    ) -> Dict[str, Any]:
        async with httpx.AsyncClient(
            headers={"Authorization": f"Bearer {self.api_key}"},
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            response = await client.post(url, json=data)
            await self._async_error_handling(response)
            return response.json()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/environment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gateway/environment.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8f\x05\n\x0b\x45nvironment\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\ncreated_by\x18\x06 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x31\n\x05state\x18\n \x01(\x0e\x32\x1a.gateway.Environment.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x0b \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12:\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1e\n\x0e\x62\x61se_image_ref\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x19\n\timage_ref\x18\x04 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\"\n\x12snapshot_image_ref\x18\x08 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x0e\n\x06shared\x18\x0c \x01(\x08\x12?\n\x0b\x61nnotations\x18\t \x03(\x0b\x32%.gateway.Environment.AnnotationsEntryB\x03\xe0\x41\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x10\n\x0c\x44ISCONNECTED\x10\x02\x12\x0e\n\nCONNECTING\x10\x03\x12\r\n\tCONNECTED\x10\x04\x12\x11\n\rDISCONNECTING\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\"s\n\x15\x45nvironmentConnection\x12\x19\n\x0cnode_pool_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tnum_ranks\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x11\n\x04role\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x14\n\x04zone\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\"|\n\x18\x43reateEnvironmentRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12.\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x14.gateway.EnvironmentB\x03\xe0\x41\x02\x12\x1b\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"*\n\x15GetEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8b\x01\n\x17ListEnvironmentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"s\n\x18ListEnvironmentsResponse\x12*\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x14.gateway.Environment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"J\n\x18UpdateEnvironmentRequest\x12.\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x14.gateway.EnvironmentB\x03\xe0\x41\x02\"-\n\x18\x44\x65leteEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"I\n\x1e\x42\x61tchDeleteEnvironmentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\"\x84\x01\n\x19\x43onnectEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x37\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x03\xe0\x41\x02\x12\x1b\n\x0evscode_version\x18\x03 \x01(\tB\x03\xe0\x41\x01\"c\n\x1c\x44isconnectEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05\x66orce\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1c\n\x0freset_snapshots\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.environment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _ENVIRONMENT_ANNOTATIONSENTRY._options = None
  _ENVIRONMENT_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _ENVIRONMENT.fields_by_name['name']._options = None
  _ENVIRONMENT.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['display_name']._options = None
  _ENVIRONMENT.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _ENVIRONMENT.fields_by_name['create_time']._options = None
  _ENVIRONMENT.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['created_by']._options = None
  _ENVIRONMENT.fields_by_name['created_by']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['state']._options = None
  _ENVIRONMENT.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['status']._options = None
  _ENVIRONMENT.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['connection']._options = None
  _ENVIRONMENT.fields_by_name['connection']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['base_image_ref']._options = None
  _ENVIRONMENT.fields_by_name['base_image_ref']._serialized_options = b'\340A\001\340A\005'
  _ENVIRONMENT.fields_by_name['image_ref']._options = None
  _ENVIRONMENT.fields_by_name['image_ref']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['snapshot_image_ref']._options = None
  _ENVIRONMENT.fields_by_name['snapshot_image_ref']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['annotations']._options = None
  _ENVIRONMENT.fields_by_name['annotations']._serialized_options = b'\340A\001'
  _ENVIRONMENTCONNECTION.fields_by_name['node_pool_id']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['node_pool_id']._serialized_options = b'\340A\002'
  _ENVIRONMENTCONNECTION.fields_by_name['num_ranks']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['num_ranks']._serialized_options = b'\340A\001'
  _ENVIRONMENTCONNECTION.fields_by_name['role']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['role']._serialized_options = b'\340A\001'
  _ENVIRONMENTCONNECTION.fields_by_name['zone']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['zone']._serialized_options = b'\340A\003\340A\005'
  _CREATEENVIRONMENTREQUEST.fields_by_name['parent']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment']._serialized_options = b'\340A\002'
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment_id']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment_id']._serialized_options = b'\340A\002'
  _GETENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _GETENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTENVIRONMENTSREQUEST.fields_by_name['parent']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_size']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_token']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTENVIRONMENTSREQUEST.fields_by_name['filter']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTENVIRONMENTSREQUEST.fields_by_name['order_by']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEENVIRONMENTREQUEST.fields_by_name['environment']._options = None
  _UPDATEENVIRONMENTREQUEST.fields_by_name['environment']._serialized_options = b'\340A\002'
  _DELETEENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _DELETEENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['parent']._options = None
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['names']._options = None
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['names']._serialized_options = b'\340A\002'
  _CONNECTENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _CONNECTENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _CONNECTENVIRONMENTREQUEST.fields_by_name['connection']._options = None
  _CONNECTENVIRONMENTREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _CONNECTENVIRONMENTREQUEST.fields_by_name['vscode_version']._options = None
  _CONNECTENVIRONMENTREQUEST.fields_by_name['vscode_version']._serialized_options = b'\340A\001'
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['force']._options = None
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['force']._serialized_options = b'\340A\001'
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['reset_snapshots']._options = None
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['reset_snapshots']._serialized_options = b'\340A\001'
  _ENVIRONMENT._serialized_start=127
  _ENVIRONMENT._serialized_end=782
  _ENVIRONMENT_ANNOTATIONSENTRY._serialized_start=604
  _ENVIRONMENT_ANNOTATIONSENTRY._serialized_end=654
  _ENVIRONMENT_STATE._serialized_start=656
  _ENVIRONMENT_STATE._serialized_end=782
  _ENVIRONMENTCONNECTION._serialized_start=784
  _ENVIRONMENTCONNECTION._serialized_end=899
  _CREATEENVIRONMENTREQUEST._serialized_start=901
  _CREATEENVIRONMENTREQUEST._serialized_end=1025
  _GETENVIRONMENTREQUEST._serialized_start=1027
  _GETENVIRONMENTREQUEST._serialized_end=1069
  _LISTENVIRONMENTSREQUEST._serialized_start=1072
  _LISTENVIRONMENTSREQUEST._serialized_end=1211
  _LISTENVIRONMENTSRESPONSE._serialized_start=1213
  _LISTENVIRONMENTSRESPONSE._serialized_end=1328
  _UPDATEENVIRONMENTREQUEST._serialized_start=1330
  _UPDATEENVIRONMENTREQUEST._serialized_end=1404
  _DELETEENVIRONMENTREQUEST._serialized_start=1406
  _DELETEENVIRONMENTREQUEST._serialized_end=1451
  _BATCHDELETEENVIRONMENTSREQUEST._serialized_start=1453
  _BATCHDELETEENVIRONMENTSREQUEST._serialized_end=1526
  _CONNECTENVIRONMENTREQUEST._serialized_start=1529
  _CONNECTENVIRONMENTREQUEST._serialized_end=1661
  _DISCONNECTENVIRONMENTREQUEST._serialized_start=1663
  _DISCONNECTENVIRONMENTREQUEST._serialized_end=1762
# @@protoc_insertion_point(module_scope)



import os
from .completion import Completion
from .chat_completion import ChatCompletion
from .model import Model

with open(
    os.path.join(os.path.dirname(os.path.abspath(__file__)), "VERSION"), "r"
) as f:
    __version__ = f.read().strip()

api_key = os.environ.get("FIREWORKS_API_KEY")
base_url = os.environ.get("FIREWORKS_API_BASE", "https://api.fireworks.ai/inference/v1")

__all__ = [
    "__version__",
    "ChatCompletion",
    "Completion",
    "Model",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/aws_iam_role_binding.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"gateway/aws_iam_role_binding.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x93\x01\n\x11\x41wsIamRoleBinding\x12\x1a\n\naccount_id\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\tprincipal\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02\"t\n\x1e\x43reateAwsIamRoleBindingRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\"\x91\x01\n\x1dListAwsIamRoleBindingsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"\x88\x01\n\x1eListAwsIamRoleBindingsResponse\x12\x39\n\x15\x61ws_iam_role_bindings\x18\x01 \x03(\x0b\x32\x1a.gateway.AwsIamRoleBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"_\n\x1e\x44\x65leteAwsIamRoleBindingRequest\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.aws_iam_role_binding_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _AWSIAMROLEBINDING.fields_by_name['account_id']._options = None
  _AWSIAMROLEBINDING.fields_by_name['account_id']._serialized_options = b'\340A\003\340A\005'
  _AWSIAMROLEBINDING.fields_by_name['create_time']._options = None
  _AWSIAMROLEBINDING.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _AWSIAMROLEBINDING.fields_by_name['principal']._options = None
  _AWSIAMROLEBINDING.fields_by_name['principal']._serialized_options = b'\340A\002'
  _AWSIAMROLEBINDING.fields_by_name['role']._options = None
  _AWSIAMROLEBINDING.fields_by_name['role']._serialized_options = b'\340A\002'
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['parent']._options = None
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._serialized_options = b'\340A\002'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['parent']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_size']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_token']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['filter']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['order_by']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
  _DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._serialized_options = b'\340A\002'
  _AWSIAMROLEBINDING._serialized_start=114
  _AWSIAMROLEBINDING._serialized_end=261
  _CREATEAWSIAMROLEBINDINGREQUEST._serialized_start=263
  _CREATEAWSIAMROLEBINDINGREQUEST._serialized_end=379
  _LISTAWSIAMROLEBINDINGSREQUEST._serialized_start=382
  _LISTAWSIAMROLEBINDINGSREQUEST._serialized_end=527
  _LISTAWSIAMROLEBINDINGSRESPONSE._serialized_start=530
  _LISTAWSIAMROLEBINDINGSRESPONSE._serialized_end=666
  _DELETEAWSIAMROLEBINDINGREQUEST._serialized_start=668
  _DELETEAWSIAMROLEBINDINGREQUEST._serialized_end=763
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gateway/user.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x04User\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x11\n\x04role\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\x05\x65mail\x18\x04 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\"`\n\x11\x43reateUserRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12 \n\x04user\x18\x02 \x01(\x0b\x32\r.gateway.UserB\x03\xe0\x41\x02\x12\x14\n\x07user_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"#\n\x0eGetUserRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x84\x01\n\x10ListUsersRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"^\n\x11ListUsersResponse\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.gateway.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"5\n\x11UpdateUserRequest\x12 \n\x04user\x18\x01 \x01(\x0b\x32\r.gateway.UserB\x03\xe0\x41\x02\"&\n\x11\x44\x65leteUserRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _USER.fields_by_name['name']._options = None
  _USER.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _USER.fields_by_name['display_name']._options = None
  _USER.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _USER.fields_by_name['create_time']._options = None
  _USER.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _USER.fields_by_name['role']._options = None
  _USER.fields_by_name['role']._serialized_options = b'\340A\002'
  _USER.fields_by_name['email']._options = None
  _USER.fields_by_name['email']._serialized_options = b'\340A\002\340A\005'
  _CREATEUSERREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEUSERREQUEST.fields_by_name['user']._options = None
  _CREATEUSERREQUEST.fields_by_name['user']._serialized_options = b'\340A\002'
  _CREATEUSERREQUEST.fields_by_name['user_id']._options = None
  _CREATEUSERREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _GETUSERREQUEST.fields_by_name['name']._options = None
  _GETUSERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTUSERSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTUSERSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['filter']._options = None
  _LISTUSERSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['order_by']._options = None
  _LISTUSERSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEUSERREQUEST.fields_by_name['user']._options = None
  _UPDATEUSERREQUEST.fields_by_name['user']._serialized_options = b'\340A\002'
  _DELETEUSERREQUEST.fields_by_name['name']._options = None
  _DELETEUSERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _USER._serialized_start=98
  _USER._serialized_end=252
  _CREATEUSERREQUEST._serialized_start=254
  _CREATEUSERREQUEST._serialized_end=350
  _GETUSERREQUEST._serialized_start=352
  _GETUSERREQUEST._serialized_end=387
  _LISTUSERSREQUEST._serialized_start=390
  _LISTUSERSREQUEST._serialized_end=522
  _LISTUSERSRESPONSE._serialized_start=524
  _LISTUSERSRESPONSE._serialized_end=618
  _UPDATEUSERREQUEST._serialized_start=620
  _UPDATEUSERREQUEST._serialized_end=673
  _DELETEUSERREQUEST._serialized_start=675
  _DELETEUSERREQUEST._serialized_end=713
# @@protoc_insertion_point(module_scope)



from .api import CompletionResponse, CompletionStreamResponse
from .base_completion import BaseCompletion


class Completion(BaseCompletion):
    """
    Class for handling text completions.
    """

    endpoint = "completions"
    response_class = CompletionResponse
    stream_response_class = CompletionStreamResponse

    @classmethod
    def _get_data_key(cls) -> str:
        return "prompt"



from .api import ChatCompletionResponse, ChatCompletionStreamResponse
from .base_completion import BaseCompletion


class ChatCompletion(BaseCompletion):
    """
    Class for handling chat completions.
    """

    endpoint = "chat/completions"
    response_class = ChatCompletionResponse
    stream_response_class = ChatCompletionStreamResponse

    @classmethod
    def _get_data_key(cls) -> str:
        return "messages"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/deployment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/deployment.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x05\n\nDeployment\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x08 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x30\n\x05state\x18\x05 \x01(\x0e\x32\x19.gateway.Deployment.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12 \n\x10predict_http_uri\x18\t \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12!\n\x11min_replica_count\x18\r \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11max_replica_count\x18\x0e \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fmax_addon_count\x18\x10 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1b\n\x0b\x61\x64\x64on_count\x18\x11 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\nbase_model\x18\x12 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12+\n\x1b\x64isaggregated_prefill_count\x18\x13 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1e\n\x0emax_batch_size\x18\x14 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x30\n\x0e\x61ws_deployment\x18\x15 \x01(\x0b\x32\x16.gateway.AwsDeploymentH\x00\x12\x30\n\x0egcp_deployment\x18\x16 \x01(\x0b\x32\x16.gateway.GcpDeploymentH\x00\x12\x12\n\nno_knative\x18\x17 \x01(\x08\"_\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x42\x06\n\x04type\"\x0f\n\rAwsDeployment\"\x0f\n\rGcpDeployment\"s\n\x17\x43reateDeploymentRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12,\n\ndeployment\x18\x02 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x04 \x01(\tB\x03\xe0\x41\x01\")\n\x14GetDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8a\x01\n\x16ListDeploymentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"p\n\x17ListDeploymentsResponse\x12(\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x13.gateway.Deployment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"G\n\x17UpdateDeploymentRequest\x12,\n\ndeployment\x18\x01 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\",\n\x17\x44\x65leteDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"+\n\x16StartDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.deployment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _DEPLOYMENT.fields_by_name['name']._options = None
  _DEPLOYMENT.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['display_name']._options = None
  _DEPLOYMENT.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _DEPLOYMENT.fields_by_name['description']._options = None
  _DEPLOYMENT.fields_by_name['description']._serialized_options = b'\340A\001'
  _DEPLOYMENT.fields_by_name['create_time']._options = None
  _DEPLOYMENT.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['state']._options = None
  _DEPLOYMENT.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['status']._options = None
  _DEPLOYMENT.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['predict_http_uri']._options = None
  _DEPLOYMENT.fields_by_name['predict_http_uri']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['min_replica_count']._options = None
  _DEPLOYMENT.fields_by_name['min_replica_count']._serialized_options = b'\340A\001\340A\005'
  _DEPLOYMENT.fields_by_name['max_replica_count']._options = None
  _DEPLOYMENT.fields_by_name['max_replica_count']._serialized_options = b'\340A\001\340A\005'
  _DEPLOYMENT.fields_by_name['max_addon_count']._options = None
  _DEPLOYMENT.fields_by_name['max_addon_count']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['addon_count']._options = None
  _DEPLOYMENT.fields_by_name['addon_count']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['base_model']._options = None
  _DEPLOYMENT.fields_by_name['base_model']._serialized_options = b'\340A\002\340A\005'
  _DEPLOYMENT.fields_by_name['disaggregated_prefill_count']._options = None
  _DEPLOYMENT.fields_by_name['disaggregated_prefill_count']._serialized_options = b'\340A\001\340A\005'
  _DEPLOYMENT.fields_by_name['max_batch_size']._options = None
  _DEPLOYMENT.fields_by_name['max_batch_size']._serialized_options = b'\340A\001\340A\005'
  _CREATEDEPLOYMENTREQUEST.fields_by_name['parent']._options = None
  _CREATEDEPLOYMENTREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
  _CREATEDEPLOYMENTREQUEST.fields_by_name['deployment']._serialized_options = b'\340A\002'
  _CREATEDEPLOYMENTREQUEST.fields_by_name['model_id']._options = None
  _CREATEDEPLOYMENTREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\001'
  _GETDEPLOYMENTREQUEST.fields_by_name['name']._options = None
  _GETDEPLOYMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['parent']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_size']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_token']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['filter']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['order_by']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
  _UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment']._serialized_options = b'\340A\002'
  _DELETEDEPLOYMENTREQUEST.fields_by_name['name']._options = None
  _DELETEDEPLOYMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _STARTDEPLOYMENTREQUEST.fields_by_name['name']._options = None
  _STARTDEPLOYMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DEPLOYMENT._serialized_start=126
  _DEPLOYMENT._serialized_end=857
  _DEPLOYMENT_STATE._serialized_start=754
  _DEPLOYMENT_STATE._serialized_end=849
  _AWSDEPLOYMENT._serialized_start=859
  _AWSDEPLOYMENT._serialized_end=874
  _GCPDEPLOYMENT._serialized_start=876
  _GCPDEPLOYMENT._serialized_end=891
  _CREATEDEPLOYMENTREQUEST._serialized_start=893
  _CREATEDEPLOYMENTREQUEST._serialized_end=1008
  _GETDEPLOYMENTREQUEST._serialized_start=1010
  _GETDEPLOYMENTREQUEST._serialized_end=1051
  _LISTDEPLOYMENTSREQUEST._serialized_start=1054
  _LISTDEPLOYMENTSREQUEST._serialized_end=1192
  _LISTDEPLOYMENTSRESPONSE._serialized_start=1194
  _LISTDEPLOYMENTSRESPONSE._serialized_end=1306
  _UPDATEDEPLOYMENTREQUEST._serialized_start=1308
  _UPDATEDEPLOYMENTREQUEST._serialized_end=1379
  _DELETEDEPLOYMENTREQUEST._serialized_start=1381
  _DELETEDEPLOYMENTREQUEST._serialized_end=1425
  _STARTDEPLOYMENTREQUEST._serialized_start=1427
  _STARTDEPLOYMENTREQUEST._serialized_end=1470
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/account.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe4\x02\n\x07\x41\x63\x63ount\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12#\n\x13prometheus_endpoint\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12/\n\x1f\x61thena_cost_usage_report_bucket\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12:\n\x0c\x61\x63\x63ount_type\x18\x06 \x01(\x0e\x32\x1c.gateway.Account.AccountTypeB\x06\xe0\x41\x03\xe0\x41\x05\"]\n\x0b\x41\x63\x63ountType\x12\x1c\n\x18\x41\x43\x43OUNT_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDEVELOPER\x10\x01\x12\x0e\n\nENTERPRISE\x10\x02\x12\x11\n\rDEVELOPER_PRO\x10\x03\"W\n\x14\x43reateAccountRequest\x12&\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x03\xe0\x41\x02\x12\x17\n\naccount_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"&\n\x11GetAccountRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"r\n\x13ListAccountsRequest\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"g\n\x14ListAccountsResponse\x12\"\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x10.gateway.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\">\n\x14UpdateAccountRequest\x12&\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x03\xe0\x41\x02\")\n\x14\x44\x65leteAccountRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.account_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _ACCOUNT.fields_by_name['name']._options = None
  _ACCOUNT.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _ACCOUNT.fields_by_name['display_name']._options = None
  _ACCOUNT.fields_by_name['display_name']._serialized_options = b'\340A\005'
  _ACCOUNT.fields_by_name['create_time']._options = None
  _ACCOUNT.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _ACCOUNT.fields_by_name['prometheus_endpoint']._options = None
  _ACCOUNT.fields_by_name['prometheus_endpoint']._serialized_options = b'\340A\001\340A\005'
  _ACCOUNT.fields_by_name['athena_cost_usage_report_bucket']._options = None
  _ACCOUNT.fields_by_name['athena_cost_usage_report_bucket']._serialized_options = b'\340A\001\340A\005'
  _ACCOUNT.fields_by_name['account_type']._options = None
  _ACCOUNT.fields_by_name['account_type']._serialized_options = b'\340A\003\340A\005'
  _CREATEACCOUNTREQUEST.fields_by_name['account']._options = None
  _CREATEACCOUNTREQUEST.fields_by_name['account']._serialized_options = b'\340A\002'
  _CREATEACCOUNTREQUEST.fields_by_name['account_id']._options = None
  _CREATEACCOUNTREQUEST.fields_by_name['account_id']._serialized_options = b'\340A\002'
  _GETACCOUNTREQUEST.fields_by_name['name']._options = None
  _GETACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTACCOUNTSREQUEST.fields_by_name['page_size']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTACCOUNTSREQUEST.fields_by_name['page_token']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTACCOUNTSREQUEST.fields_by_name['filter']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTACCOUNTSREQUEST.fields_by_name['order_by']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEACCOUNTREQUEST.fields_by_name['account']._options = None
  _UPDATEACCOUNTREQUEST.fields_by_name['account']._serialized_options = b'\340A\002'
  _DELETEACCOUNTREQUEST.fields_by_name['name']._options = None
  _DELETEACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _ACCOUNT._serialized_start=101
  _ACCOUNT._serialized_end=457
  _ACCOUNT_ACCOUNTTYPE._serialized_start=364
  _ACCOUNT_ACCOUNTTYPE._serialized_end=457
  _CREATEACCOUNTREQUEST._serialized_start=459
  _CREATEACCOUNTREQUEST._serialized_end=546
  _GETACCOUNTREQUEST._serialized_start=548
  _GETACCOUNTREQUEST._serialized_end=586
  _LISTACCOUNTSREQUEST._serialized_start=588
  _LISTACCOUNTSREQUEST._serialized_end=702
  _LISTACCOUNTSRESPONSE._serialized_start=704
  _LISTACCOUNTSRESPONSE._serialized_end=807
  _UPDATEACCOUNTREQUEST._serialized_start=809
  _UPDATEACCOUNTREQUEST._serialized_end=871
  _DELETEACCOUNTREQUEST._serialized_start=873
  _DELETEACCOUNTREQUEST._serialized_end=914
# @@protoc_insertion_point(module_scope)



from typing import Any, Dict, List, Optional, Union
from pydantic import BaseModel, Field, validator


class TextPrompt(BaseModel):
    text: str
    weight: int


class TextToImageRequestBody(BaseModel):
    model: str = "accounts/fireworks/models/stable-diffusion-xl-1024-v1-0"
    cfg_scale: int = 7
    clip_guidance_preset: str = "NONE"
    height: int = 1024
    width: int = 1024
    sampler: Optional[str] = None
    samples: int = 1
    steps: int = 50
    seed: int = 0
    style_preset: Optional[str] = None
    text_prompts: List[TextPrompt]


class ImageToImageRequestBody(BaseModel):
    model: str = "accounts/fireworks/models/stable-diffusion-xl-1024-v1-0"
    cfg_scale: int = Field(default=7)
    clip_guidance_preset: str = "NONE"
    sampler: Optional[str]
    samples: int = 1
    steps: int = 50
    seed: int = 0
    style_preset: Optional[str]

    init_image_mode: str = "IMAGE_STRENGTH"
    image_strength: Optional[float]
    step_schedule_start: Optional[float] = 0.65
    step_schedule_end: Optional[float]

    @validator("image_strength", pre=True, always=True)
    def validate_image_strength(cls, v, values):
        if values["init_image_mode"] == "IMAGE_STRENGTH" and v is None:
            raise ValueError(
                "image_strength is required when init_image_mode is IMAGE_STRENGTH"
            )
        return v

    @validator("step_schedule_start", "step_schedule_end", pre=True, always=True)
    def validate_step_schedule(cls, v, values):
        if values["init_image_mode"] == "STEP_SCHEDULE" and v is None:
            raise ValueError(
                "Both step_schedule_start and step_schedule_end are required when init_image_mode is STEP_SCHEDULE"
            )
        return v



import unittest
import fireworks.client


class TestBasic(unittest.TestCase):
    def test_import(self):
        self.assertRegex(fireworks.client.__version__, r"^\d+\.\d+\.\d+([a]\d+)?$")


if __name__ == "__main__":
    unittest.main()
